@@ -471,6 +471,7 @@ enum ikev2_trans_type_prf {
 };
 
 enum ikev2_trans_type_integ {
+	IKEv2_AUTH_NONE        =0,
 	IKEv2_AUTH_HMAC_MD5_96 =1,
 	IKEv2_AUTH_HMAC_SHA1_96=2,
 	IKEv2_AUTH_DES_MAC     =3,
@@ -487,7 +488,12 @@ enum ikev2_trans_type_esn {
 	IKEv2_ESN_DISABLED = 0,
 	IKEv2_ESN_ENABLED  = 1,
 };
-	
+
+/* RFC 4306 Section 3.3.5 */	
+enum ikev2_trans_attr_type {
+	IKEv2_KEY_LENGTH = 14,
+};
+
 
 /* many transform values are moved to openswan/ipsec_policy.h
  * including all of the following, which are here so that
@@ -656,6 +662,8 @@ enum ikev1_auth_attribute {
 	AUTH_ALGORITHM_HMAC_SHA2_384=6,
 	AUTH_ALGORITHM_HMAC_SHA2_512=7,
 	AUTH_ALGORITHM_HMAC_RIPEMD=8,
+	AUTH_ALGORITHM_AES_CBC=9,
+	AUTH_ALGORITHM_NULL=251,
 };
 
 typedef u_int16_t ipsec_auth_t;
