@@ -547,7 +547,7 @@ enum_names enc_mode_names =
 /* Auth Algorithm attribute */
 
 static const char *const auth_alg_name[] = {
-	"unspecified AUTH_ALGORITHM",
+	"AUTH_ALGORITHM_NONE", /* our own value, not standard */
 	"AUTH_ALGORITHM_HMAC_MD5",
 	"AUTH_ALGORITHM_HMAC_SHA1",
 	"AUTH_ALGORITHM_DES_MAC",
@@ -557,19 +557,17 @@ static const char *const auth_alg_name[] = {
 	"AUTH_ALGORITHM_HMAC_SHA2_512",
 	"AUTH_ALGORITHM_HMAC_RIPEMD",
 	"AUTH_ALGORITHM_AES_CBC",
-	"AUTH_ALGORITHM_ID10",
-	"AUTH_ALGORITHM_ID11",
-	"AUTH_ALGORITHM_ID12",
-	"AUTH_ALGORITHM_ID13",
-	"AUTH_ALGORITHM_ID14",
-	"AUTH_ALGORITHM_ID15",
+    };
+
+static const char *const null_auth_alg_name[] = {
+	"AUTH_ALGORITHM_NULL", /* 251 */
     };
 
 enum_names
+    null_auth_alg_names =
+	{ AUTH_ALGORITHM_NULL, AUTH_ALGORITHM_NULL, null_auth_alg_name, NULL },
     auth_alg_names =
-	{ AUTH_ALGORITHM_HMAC_MD5, 15 /* AUTH_ALGORITHM_HMAC_RIPEMD */, auth_alg_name + 1, NULL },
-    extended_auth_alg_names =
-	{ AUTH_ALGORITHM_NONE, AUTH_ALGORITHM_KPDK, auth_alg_name, NULL };
+	{ AUTH_ALGORITHM_NONE, AUTH_ALGORITHM_AES_CBC , auth_alg_name, &null_auth_alg_names };
 
 /* From draft-beaulieu-ike-xauth */
 const char *const xauth_attr_name[] = {
@@ -981,6 +979,7 @@ enum_names trans_type_prf_names =
 
 /* Transform-type Integrity */
 const char *const trans_type_integ_name[]={
+    "auth-none",
     "auth-hmac-md5-96",
     "auth-hmac-sha1-96",
     "auth-des-mac",
@@ -988,7 +987,7 @@ const char *const trans_type_integ_name[]={
     "auth-aes-xcbc-96",
 };
 enum_names trans_type_integ_names =
-{ IKEv2_AUTH_HMAC_MD5_96, IKEv2_AUTH_AES_XCBC_96, trans_type_integ_name, NULL};
+{ IKEv2_AUTH_NONE, IKEv2_AUTH_AES_XCBC_96, trans_type_integ_name, NULL};
 
 /* Transform-type Integrity */
 const char *const trans_type_esn_name[]={
@@ -1019,7 +1018,37 @@ enum_names *ikev2_transid_val_descs[] = {
     &trans_type_esn_names,  /* 5 */
 };
 const unsigned int ikev2_transid_val_descs_size = elemsof(ikev2_transid_val_descs);
-    
+
+/* Transform Attributes */
+const char *const ikev2_trans_attr_name[]={
+    "KEY_LENGTH",
+};
+
+enum_names ikev2_trans_attr_descs = {
+    IKEv2_KEY_LENGTH + ISAKMP_ATTR_AF_TV,
+    IKEv2_KEY_LENGTH + ISAKMP_ATTR_AF_TV,
+    ikev2_trans_attr_name, NULL };
+
+/* for each IKEv2 attribute, which enum_names describes its values? */
+enum_names *ikev2_trans_attr_val_descs[] = {
+	NULL,			/* 0 */
+	NULL,			/* 1 */
+	NULL,			/* 2 */
+	NULL,			/* 3 */
+	NULL,			/* 4 */
+	NULL,			/* 5 */
+	NULL,			/* 6 */
+	NULL,			/* 7 */
+	NULL,			/* 8 */
+	NULL,			/* 9 */
+	NULL,			/* 10 */
+	NULL,			/* 11 */
+	NULL,			/* 12 */
+	NULL,			/* 13 */
+	&ikev2_trans_attr_descs,/* KEY_LENGTH */
+    };
+const unsigned int ikev2_trans_attr_val_descs_size=elemsof(ikev2_trans_attr_val_descs);
+
 
 /* socket address family info */
 
