@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_xform.h,v 1.41 2004-07-10 19:08:41 mcr Exp $
+ * RCSID $Id: ipsec_xform.h,v 1.42 2005/08/05 08:50:45 mcr Exp $
  */
 
 #ifndef _IPSEC_XFORM_H_
@@ -44,6 +44,7 @@
  * draft-ietf-ipsec-doi-tc-mib-02.txt
  */
 
+/* why are these hardcoded here? See ipsec_policy.h for their enums -- Paul*/
 #define AH_NONE			0
 #define AH_MD5			2
 #define AH_SHA			3
@@ -52,7 +53,9 @@
 #define AH_SHA2_384		6
 #define AH_SHA2_512		7
 #define AH_RIPEMD		8
-#define AH_MAX			15
+#define AH_AES			9
+#define AH_NULL			251
+#define AH_MAX			251
 
 /* IPsec ESP transform values */
 
@@ -124,6 +127,8 @@ static inline const char *auth_name_id (unsigned id) {
 	auth_name_id(x->ips_authalg) /* "_UNKNOWN_auth" */ \
 
 #ifdef __KERNEL__
+#include <linux/skbuff.h>
+
 struct ipsec_rcv_state;
 struct ipsec_xmit_state;
 
@@ -166,7 +171,11 @@ extern void ipsec_dmp(char *s, caddr_t bb, int len);
 
 /*
  * $Log: ipsec_xform.h,v $
- * Revision 1.41  2004-07-10 19:08:41  mcr
+ * Revision 1.42  2005/08/05 08:50:45  mcr
+ * 	move #include of skbuff.h to a place where
+ * 	we know it will be kernel only code.
+ *
+ * Revision 1.41  2004/07/10 19:08:41  mcr
  * 	CONFIG_IPSEC -> CONFIG_KLIPS.
  *
  * Revision 1.40  2004/04/06 02:49:08  mcr
