@@ -42,7 +42,7 @@
 /*	Low freeswan header coupling	*/
 #include "openswan/ipsec_xform.h"
 #include "openswan/ipsec_alg.h"
-#include "crypto/des.h"
+#include "klips-crypto/des.h"
 #include "openswan/ipsec_alg_3des.h"
 
 #define AES_CONTEXT_T aes_context
@@ -53,9 +53,9 @@ static int excl_3des=0;
 #if defined(CONFIG_KLIPS_ENC_3DES_MODULE)
 MODULE_AUTHOR("Michael Richardson <mcr@xelerance.com>");
 #ifdef module_param
-module_param(debug_3des,int,0600)
-module_param(test_des,int,0600)
-module_param(excl_des,int,0600)
+module_param(debug_3des, int, 0664);
+module_param(test_des, int, 0664);
+module_param(excl_des, int, 0664);
 #else
 MODULE_PARM(debug_3des, "i");
 MODULE_PARM(test_des, "i");
@@ -122,6 +122,7 @@ static struct ipsec_alg_enc ipsec_alg_3DES = {
 			ixt_support: {
 			  ias_exttype:	  IPSEC_ALG_TYPE_ENCRYPT,
 			  ias_id: 	  ESP_3DES,
+			  //ias_ivlen:      64,
 			  ias_keyminbits: ESP_3DES_KEY_SZ*8,
 			  ias_keymaxbits: ESP_3DES_KEY_SZ*8,
 		},
