@@ -204,7 +204,7 @@ compute_proto_keymat(struct state *st
     switch (protoid)
     {
     case PROTO_IPSEC_ESP:
-	    switch (pi->attrs.transid)
+	    switch (pi->attrs.transattrs.encrypt)
 	    {
 	    case ESP_NULL:
 		needed_len = 0;
@@ -219,17 +219,17 @@ compute_proto_keymat(struct state *st
 		needed_len = AES_CBC_BLOCK_SIZE;
 
 		/* if an attribute is set, then use that! */
-		if(st->st_esp.attrs.key_len) {
-		    needed_len = st->st_esp.attrs.key_len/8;
+		if(st->st_esp.attrs.transattrs.enckeylen) {
+		    needed_len = st->st_esp.attrs.transattrs.enckeylen/8;
 		}
 		break;
 
 	    default:
 #ifdef KERNEL_ALG
-		if((needed_len=kernel_alg_esp_enc_keylen(pi->attrs.transid))>0) {
+		if((needed_len=kernel_alg_esp_enc_keylen(pi->attrs.transattrs.encrypt))>0) {
 			/* XXX: check key_len "coupling with kernel.c's */
-			if (pi->attrs.key_len) {
-				needed_len=pi->attrs.key_len/8;
+			if (pi->attrs.transattrs.enckeylen) {
+				needed_len=pi->attrs.transattrs.enckeylen/8;
 				DBG(DBG_PARSING, DBG_log("compute_proto_keymat:"
 						"key_len=%d from peer",
 						(int)needed_len));
@@ -237,13 +237,13 @@ compute_proto_keymat(struct state *st
 			break;
 		}
 #endif
-		bad_case(pi->attrs.transid);
+		bad_case(pi->attrs.transattrs.encrypt);
 	    }
 	    DBG(DBG_PARSING, DBG_log("compute_proto_keymat:"
 				     "needed_len (after ESP enc)=%d",
 				     (int)needed_len));
 
-	    switch (pi->attrs.auth)
+	    switch (pi->attrs.transattrs.integ_hash)
 	    {
 	    case AUTH_ALGORITHM_NONE:
 		break;
@@ -255,13 +255,13 @@ compute_proto_keymat(struct state *st
 		break;
 	    default:
 #ifdef KERNEL_ALG
-	      if (kernel_alg_esp_auth_ok(pi->attrs.auth, NULL) == NULL) {
-		needed_len += kernel_alg_esp_auth_keylen(pi->attrs.auth);
-		break;
+	      if (kernel_alg_esp_auth_ok(pi->attrs.transattrs.integ_hash, NULL) == NULL) {
+		  needed_len += kernel_alg_esp_auth_keylen(pi->attrs.transattrs.integ_hash);
+		  break;
 	      } 
 #endif
 	    case AUTH_ALGORITHM_DES_MAC:
-		bad_case(pi->attrs.auth);
+		bad_case(pi->attrs.transattrs.integ_hash);
 		break;
 	      
 	    }
@@ -271,7 +271,7 @@ compute_proto_keymat(struct state *st
 	    break;
 
     case PROTO_IPSEC_AH:
-	    switch (pi->attrs.transid)
+	    switch (pi->attrs.transattrs.encrypt)
 	    {
 	    case AH_MD5:
 		needed_len = HMAC_MD5_KEY_LEN;
@@ -281,12 +281,12 @@ compute_proto_keymat(struct state *st
 		break;
 	    default:
 #ifdef KERNEL_ALG
-		if (kernel_alg_ah_auth_ok(pi->attrs.auth, NULL)) {
-		    needed_len += kernel_alg_ah_auth_keylen(pi->attrs.auth);
+		if (kernel_alg_ah_auth_ok(pi->attrs.transattrs.integ_hash, NULL)) {
+		    needed_len += kernel_alg_ah_auth_keylen(pi->attrs.transattrs.integ_hash);
 		    break;
 		} 
 #endif
-		bad_case(pi->attrs.transid);
+		bad_case(pi->attrs.transattrs.encrypt);
 	    }
 	    break;
 
@@ -306,7 +306,7 @@ compute_proto_keymat(struct state *st
 	size_t needed_space;	/* space needed for keying material (rounded up) */
 	size_t i;
 
-	hmac_init_chunk(&ctx_me, st->st_oakley.hasher, st->st_skeyid_d);
+	hmac_init_chunk(&ctx_me, st->st_oakley.prf_hasher, st->st_skeyid_d);
 	ctx_peer = ctx_me;	/* duplicate initial conditions */
 
 	needed_space = needed_len + pad_up(needed_len, ctx_me.hmac_digest_len);
@@ -545,11 +545,11 @@ decode_net_id(struct isakmp_ipsec_id *id
 /* like decode, but checks that what is received matches what was sent */
 static bool
 check_net_id(struct isakmp_ipsec_id *id
-	     , pb_stream *id_pbs
-	     , u_int8_t *protoid
-	     , u_int16_t *port
-	     , ip_subnet *net
-	     , const char *which)
+, pb_stream *id_pbs
+, u_int8_t *protoid
+, u_int16_t *port
+, ip_subnet *net
+, const char *which)
 {
     ip_subnet net_temp;
     bool bad_proposal=FALSE;
@@ -618,7 +618,7 @@ quick_mode_hash12(u_char *dest, const u_char *start, const u_char *roof
     }
     DBG_dump("hash key", st->st_skeyid_a.ptr, st->st_skeyid_a.len);
 #endif
-    hmac_init_chunk(&ctx, st->st_oakley.hasher, st->st_skeyid_a);
+    hmac_init_chunk(&ctx, st->st_oakley.prf_hasher, st->st_skeyid_a);
     hmac_update(&ctx, (const void *) msgid, sizeof(msgid_t));
     if (hash2)
 	hmac_update_chunk(&ctx, st->st_ni);	/* include Ni_b in the hash */
@@ -643,7 +643,7 @@ quick_mode_hash3(u_char *dest, struct state *st)
 {
     struct hmac_ctx ctx;
 
-    hmac_init_chunk(&ctx, st->st_oakley.hasher, st->st_skeyid_a);
+    hmac_init_chunk(&ctx, st->st_oakley.prf_hasher, st->st_skeyid_a);
     hmac_update(&ctx, (const u_char *)"\0", 1);
     hmac_update(&ctx, (u_char *) &st->st_msgid, sizeof(st->st_msgid));
     hmac_update_chunk(&ctx, st->st_ni);
@@ -659,7 +659,7 @@ quick_mode_hash3(u_char *dest, struct state *st)
 void
 init_phase2_iv(struct state *st, const msgid_t *msgid)
 {
-    const struct hash_desc *h = st->st_oakley.hasher;
+    const struct hash_desc *h = st->st_oakley.prf_hasher;
     union hash_ctx ctx;
 
     DBG_cond_dump(DBG_CRYPT, "last Phase 1 IV:"
@@ -1290,7 +1290,7 @@ quick_inI1_outR1_continue(struct adns_continuation *cr, err_t ugh)
 	{
 	    r = quick_inI1_outR1_authtail(b, cr);
 	}
-	complete_state_transition(&b->md, r);
+	complete_v1_state_transition(&b->md, r);
     }
     if (b->md != NULL)
 	release_md(b->md);
@@ -1875,7 +1875,7 @@ quick_inI1_outR1_authtail(struct verify_oppo_bundle *b
 	}
 
 	/* Ni in */
-	RETURN_STF_FAILURE(accept_nonce(md, &st->st_ni, "Ni"));
+	RETURN_STF_FAILURE(accept_v1_nonce(md, &st->st_ni, "Ni"));
 
 	/* [ KE ] in (for PFS) */
 	RETURN_STF_FAILURE(accept_PFS_KE(md, &st->st_gi
@@ -1957,7 +1957,7 @@ quick_inI1_outR1_cryptocontinue1(struct pluto_crypto_req_cont *pcrc
 	
 	if(e != STF_SUSPEND) {
 	    if(dh->md != NULL) {
-		complete_state_transition(&qke->md, e);
+		complete_v1_state_transition(&qke->md, e);
 		if(dh->md) release_md(qke->md);
 	    }
 	}
@@ -1974,7 +1974,7 @@ quick_inI1_outR1_cryptocontinue1(struct pluto_crypto_req_cont *pcrc
 
 	if(dh.md != NULL) {
 	    /* note: use qke-> pointer */
-	    complete_state_transition(&qke->md, e);
+	    complete_v1_state_transition(&qke->md, e);
 	    if(dh.md) release_md(qke->md);
 	}
     }
@@ -2009,7 +2009,7 @@ quick_inI1_outR1_cryptocontinue2(struct pluto_crypto_req_cont *pcrc
     e = quick_inI1_outR1_cryptotail(dh, r);
 
     if(dh->md != NULL) {
-	complete_state_transition(&dh->md, e);
+	complete_v1_state_transition(&dh->md, e);
 	if(dh->md) release_md(dh->md);
     }
 
@@ -2236,7 +2236,7 @@ quick_inR1_outI2(struct msg_digest *md)
     }
 
     /* Nr in */
-    RETURN_STF_FAILURE(accept_nonce(md, &st->st_nr, "Nr"));
+    RETURN_STF_FAILURE(accept_v1_nonce(md, &st->st_nr, "Nr"));
 
     /* [ KE ] in (for PFS) */
     RETURN_STF_FAILURE(accept_PFS_KE(md, &st->st_gr, "Gr", "Quick Mode R1"));
@@ -2289,7 +2289,7 @@ quick_inR1_outI2_continue(struct pluto_crypto_req_cont *pcrc
     e = quick_inR1_outI2_cryptotail(dh, r);
 
     if(dh->md != NULL) {
-	complete_state_transition(&dh->md, e);
+	complete_v1_state_transition(&dh->md, e);
 	if(dh->md) release_md(dh->md);
     }
     reset_cur_state();
@@ -2325,10 +2325,11 @@ quick_inR1_outI2_cryptotail(struct dh_continuation *dh
 	    /* ??? we are assuming IPSEC_DOI */
 
 	    /* IDci (we are initiator) */
+
 	    if (!check_net_id(&IDci->payload.ipsec_id, &IDci->pbs
-			      , &st->st_myuserprotoid, &st->st_myuserport
-			      , &st->st_connection->spd.this.client
-			      , "our client"))
+	    , &st->st_myuserprotoid, &st->st_myuserport
+	    , &st->st_connection->spd.this.client
+	    , "our client"))
 		return STF_FAIL + INVALID_ID_INFORMATION;
 
 	    /* we checked elsewhere that we got two of them */
@@ -2338,9 +2339,9 @@ quick_inR1_outI2_cryptotail(struct dh_continuation *dh
 	    /* IDcr (responder is peer) */
 
 	    if (!check_net_id(&IDcr->payload.ipsec_id, &IDcr->pbs
-			      , &st->st_peeruserprotoid, &st->st_peeruserport
-			      , &st->st_connection->spd.that.client
-			      , "peer client"))
+	    , &st->st_peeruserprotoid, &st->st_peeruserport
+	    , &st->st_connection->spd.that.client
+	    , "peer client"))
 		return STF_FAIL + INVALID_ID_INFORMATION;
 
 	    /*
