@@ -21,7 +21,9 @@ extern void ipsecdoi_initiate(int whack_sock, struct connection *c
 			      , so_serial_t replacing
 			      , enum crypto_importance importance);
 
-extern void ipsecdoi_replace(struct state *st, unsigned long try);
+extern void ipsecdoi_replace(struct state *st
+			     , lset_t policy_add, lset_t policy_del
+			     , unsigned long try);
 
 extern void init_phase2_iv(struct state *st, const msgid_t *msgid);
 
